using System;
using System.IO;
using NUnit.Framework;

namespace TopCoder.File.Statistics.Matcher
{
    /// <summary>
    /// Unit test for abstract <see cref="BinaryFileMatcher"/> class.
    /// It mainly tests the following:
    /// constructor: BinaryFileMatcher(), BinaryFileMatcher(string, string)
    /// member: Match(bool)
    ///
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (C) 2005 TopCoder Inc., All Rights Reserved.</copyright>
    /// </summary>
    [TestFixture]
    public class BinaryFileMatcherUnitTest
    {
        /// <summary>
        /// Represents an instance of <see cref="BinaryFileMatcher"/>, used to test it's public member.
        /// </summary>
        private IFileMatcher matcher;

        /// <summary>
        /// Set up for each test.
        /// </summary>
        [SetUp]
        public void RunBeforeEachTest()
        {
            matcher = new BinaryFileMatcher();
        }

        /// <summary>
        /// Test ctor BinaryFileMatcher(), instance should be created.
        /// </summary>
        public void TestCtor1()
        {
            Assert.IsNotNull(new TextFileMatcher(),
                "Failed to create instance of TextFileMatcher.");
        }

        /// <summary>
        /// Test ctor BinaryFileMatcher(string nameSpace, string prefix), with nameSpace is null,
        /// ANE is expected.
        /// </summary>
        [Test, ExpectedException(typeof(ArgumentNullException))]
        public void TestCtor2_NamespaceIsNull()
        {
            new BinaryFileMatcher(null, "prefix");
        }

        /// <summary>
        /// Test ctor TextFileMatcher(string nameSpace, string prefix), with nameSpace is empty,
        /// AE is expected.
        /// </summary>
        [Test, ExpectedException(typeof(ArgumentException))]
        public void TestCtor2_NamespaceIsEmpty()
        {
            new BinaryFileMatcher("  ", "prefix");
        }

        /// <summary>
        /// Test ctor BinaryFileMatcher(string nameSpace, string prefix), with prefix is null,
        /// ANE is expected.
        /// </summary>
        [Test, ExpectedException(typeof(ArgumentNullException))]
        public void TestCtor2_PrefixIsNull()
        {
            new BinaryFileMatcher("TopCoder", null);
        }

        /// <summary>
        /// Test ctor BinaryFileMatcher(string nameSpace, string prefix), with prefix is emtpy, allowed.
        /// </summary>
        [Test]
        public void TestCtor2_PrefixIsEmpty()
        {
            Assert.IsNotNull(new BinaryFileMatcher("TopCoder", "  "),
                "Failed to create instance of BinaryFileMatcher.");
        }

        /// <summary>
        /// Test ctor BinaryFileMatcher(string nameSpace, string prefix),
        /// with both arguments are valid, instance should be created.
        /// </summary>
        public void TestCtor2()
        {

            Assert.IsNotNull(new BinaryFileMatcher("TopCoder", "prefix"),
                "Failed to create instance of TextFileMatcher.");
        }

        /// <summary>
        /// Test Match(bool isBinary), since it is protected, test Match(FileInfo file) instead.
        /// with file is text file, false is expected.
        /// </summary>
        [Test]
        public void TestMatch_TextFile1()
        {
            Assert.IsFalse(matcher.Match(new FileInfo("../../test_files/matcher/test.txt")),
                "Failed to determine the correct file category");
        }

        /// <summary>
        /// Test Match(bool isBinary), since it is protected, test Match(FileInfo file) instead.
        /// with file is text file, false is expected.
        /// </summary>
        [Test]
        public void TestMatch_TextFile2()
        {
            Assert.IsFalse(matcher.Match(new FileInfo("../../test_files/matcher/test.big.txt")),
                "Failed to determine the correct file category");
        }

        /// <summary>
        /// Test Match(bool isBinary), since it is protected, test Match(FileInfo file) instead.
        /// with file is binary file, true is expected.
        /// </summary>
        [Test]
        public void TestMatch_BinFile1()
        {
            Assert.IsTrue(matcher.Match(new FileInfo("../../test_files/matcher/test.bin")),
                "Failed to determine the correct file category");
        }

        /// <summary>
        /// Test Match(bool isBinary), since it is protected, test Match(FileInfo file) instead.
        /// with file is binary file, true is expected.
        /// </summary>
        [Test]
        public void TestMatch_BinFile2()
        {
            Assert.IsTrue(matcher.Match(new FileInfo("../../test_files/matcher/test.big.bin")),
                "Failed to determine the correct file category");
        }
    }
}