using System;
using System.IO;
using NUnit.Framework;

namespace TopCoder.File.Statistics.Matcher
{
    /// <summary>
    /// Unit test for abstract <see cref="FileTypeMatcher"/> class, use <see cref="MockFileTypeMatcher"/> instead.
    /// It mainly tests the following:
    /// constructor: FileTypeMatcher()
    /// member: Match(FileInfo)
    ///
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (C) 2005 TopCoder Inc., All Rights Reserved.</copyright>
    /// </summary>
    [TestFixture]
    public class FileTypeMatcherUnitTest
    {
        /// <summary>
        /// Represents an instance of <see cref="FileTypeMatcher"/>, used to test it's public member.
        /// </summary>
        private IFileMatcher matcher;

        /// <summary>
        /// Set up for each test.
        /// </summary>
        [SetUp]
        public void RunBeforeEachTest()
        {
            UnitTestHelper.RemoveConfigFile(UnitTestHelper.MAGIC_NUMBER_CONFIG);
            UnitTestHelper.LoadConfigFile(UnitTestHelper.MAGIC_NUMBER_CONFIG);

            matcher = new MockFileTypeMatcher();
        }

        /// <summary>
        /// Tear down for each test.
        /// </summary>
        [Test]
        public void RunAfterEachTest()
        {
            UnitTestHelper.RemoveConfigFile(UnitTestHelper.MAGIC_NUMBER_CONFIG);
        }

        /// <summary>
        /// Test ctor FileTypeMatcher(), instance should be created.
        /// </summary>
        [Test]
        public void TestCtor()
        {
            Assert.IsNotNull(matcher, "Failed to create instance of FileTypeMatcher");
        }

        /// <summary>
        /// Test Match(FileInfo file), with file is null, ANE is expected.
        /// </summary>
        [Test, ExpectedException(typeof(ArgumentNullException))]
        public void TestMatch_FileIsNull()
        {
            matcher.Match(null);
        }

        /// <summary>
        /// Test Match(FileInfo file), with file is valid, the mock Match(FileType type) is always return true
        /// </summary>
        [Test]
        public void TestMatch1()
        {
            Assert.IsTrue(matcher.Match(new FileInfo("../../test_files/matcher/dos.exe")),
                "Mock implementation is always return true.");
        }

        /// <summary>
        /// Test Match(FileInfo file), with file is valid, the mock Match(FileType type) is always return true
        /// </summary>
        [Test]
        public void TestMatch2()
        {
            Assert.IsTrue(matcher.Match(new FileInfo("../../test_files/matcher/MagicNumber.class")),
                "Mock implementation is always return true.");
        }

        /// <summary>
        /// Test Match(FileInfo file), with file is valid, file type is unknown, false is returned.
        /// </summary>
        [Test]
        public void TestMatch3()
        {
            Assert.IsFalse(matcher.Match(new FileInfo("../../test_files/matcher/unknown")),
                "File type is unknown, false is expected.");
        }
    }
}