using System;
namespace  TopCoder.File.Statistics.Matcher
{
    /// <summary>
    /// <see cref="FileCategoryMatcher"/> concrete implementation that matches text files.
    ///
    /// <configuration>
    /// Constructor with Property is provided to address reflection contract with no real use.
    /// </configuration>
    ///
    /// <thread-safety>
    /// This class is stateless and thread-safe.
    /// </thread-safety>
    ///
    /// <author>WishingBone</author>
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (C) 2005 TopCoder Inc., All Rights Reserved.</copyright>
    /// </summary>
    public class TextFileMatcher : FileCategoryMatcher
    {
        /// <summary>
        /// Default constructor. Does nothing.
        /// </summary>
        public TextFileMatcher()
        {
        }

        /// <summary>
        /// Reflection contract. Does nothing.
        /// </summary>
        ///
        /// <param name="nameSpace">not null and empty, the namespace to load config from.</param>
        /// <param name="prefix">
        /// can be empty, the prefix indicates the global property level.</param>
        ///
        /// <exception cref="ArgumentNullException">if nameSpace or prefix is null</exception>
        /// <exception cref="ArgumentException">if nameSpace is emtpy</exception>
        public TextFileMatcher(string nameSpace, string prefix)
        {
            FileStatisticsHelper.CheckNullOrEmptyString(nameSpace, "nameSpace");
            FileStatisticsHelper.CheckNull(prefix, "prefix");
        }

        /// <summary>
        /// Simply return not isBinary.
        /// </summary>
        ///
        /// <param name="isBinary">whether file is binary</param>
        /// <returns>not isBinary</returns>
        protected override bool Match(bool isBinary)
        {
            return !isBinary;
        }
    }
}