using System;
using System.IO;
using NUnit.Framework;

namespace TopCoder.File.Statistics
{
    /// <summary>
    /// Unit test for <see cref="CommandLine"/> class.
    /// It mainly tests the following:
    /// static member: Namespace, Main
    ///
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (C) 2005 TopCoder Inc., All Rights Reserved.</copyright>
    /// </summary>
    [TestFixture]
    public class CommandLineUnitTest
    {
        /// <summary>
        /// Set up for each test.
        /// </summary>
        [SetUp]
        public void RunBeforeEachTest()
        {
            UnitTestHelper.RemoveConfigFile(UnitTestHelper.COMMANDLINE_CONFIG);
            UnitTestHelper.LoadConfigFile(UnitTestHelper.COMMANDLINE_CONFIG);
        }

        /// <summary>
        /// Tear down for each test.
        /// </summary>
        [TearDown]
        public void RunAfterEachTest()
        {
            UnitTestHelper.RemoveConfigFile(UnitTestHelper.COMMANDLINE_CONFIG);
        }

        /// <summary>
        /// Test static member Namespace, should be 'TopCoder.File.Statistics.Main'.
        /// </summary>
        [Test]
        public void TestNamespace()
        {
            Assert.AreEqual("TopCoder.File.Statistics.Main", CommandLine.Namespace,
                "Namespace of CommandLine should be 'TopCoder.File.Statistics.Main'.");
        }

        /// <summary>
        /// Test Main(), without any argument, helper message is expected.
        /// </summary>
        [Test]
        public void TestMain_ShowHelp()
        {
            // set the console output to new
            MemoryStream stream = new MemoryStream(2048);
            TextWriter newOut = new StreamWriter(stream);
            TextWriter oldOut = Console.Out;
            Console.SetOut(newOut);

            CommandLine.Main(null);

            // restore the console output
            Console.SetOut(oldOut);

            // verify the output with the usage file
            newOut.Flush();
            stream.Seek(0, SeekOrigin.Begin);
            string helper = new StreamReader(stream).ReadToEnd();
            Console.Write(helper);
        }

        /// <summary>
        /// Test Main(), the output result is reported to console.
        /// </summary>
        [Test]
        public void TestMain_Console()
        {
            // set the console output to new
            MemoryStream stream = new MemoryStream(2048);
            TextWriter newOut = new StreamWriter(stream);
            TextWriter oldOut = Console.Out;
            Console.SetOut(newOut);

            string[] args = new string[] {"-b:../../test_files/processor", "-r", "../../test_files/processor"};

            CommandLine.Main(args);

            // restore the console output
            Console.SetOut(oldOut);

            // verify the output with the usage file
            newOut.Flush();
            stream.Seek(0, SeekOrigin.Begin);
            string helper = new StreamReader(stream).ReadToEnd();

            Console.Write(helper);
        }

        /// <summary>
        /// Test Main(), the output result is reported to file.
        /// </summary>
        [Test]
        public void TestMain_File()
        {
            try
            {
                string[] args = new string[] {"-b:../../test_files/processor", "-r",
                    "-o:../../test_files/reporting/command1.out", "../../test_files/processor"};

                CommandLine.Main(args);

                string content = UnitTestHelper.ReadFileContent("../../test_files/reporting/command1.out");
            }
            catch(Exception)
            {
                throw;
            }
            finally
            {
                UnitTestHelper.DeleteFile("../../test_files/reporting/command1.out");
            }
        }
    }
}
