using System;
using NUnit.Framework;

namespace TopCoder.File.Statistics
{
    /// <summary>
    /// Unit test for <see cref="FileStatisticsException"/> class.
    /// It mainly tests the following:
    /// constructor:FileStatisticsException(string), FileStatisticsException(string, Exception)
    ///
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (C) 2005 TopCoder Inc., All Rights Reserved.</copyright>
    /// </summary>
    [TestFixture]
    public class FileStatisticsExceptionUnitTest
    {
        /// <summary>
        /// Represent the messaget to construct <see cref="FileStatisticsException"/>.
        /// </summary>
        private string message = "Unit Test";

        /// <summary>
        /// Represent the cause to construct <see cref="FileStatisticsException"/>.
        /// </summary>
        private Exception cause = new Exception();

        /// <summary>
        /// Test ctor FileStatisticsException(string message),
        /// with message is null, allowed.
        /// </summary>
        public void TestCtor1_MessageIsNull()
        {
            FileStatisticsException e = new FileStatisticsException(null);
            Assert.IsNotNull(e,
                "Failed to create instance of FileStatisticsException with message is null.");
            Assert.IsTrue(e.Message.IndexOf("TopCoder.File.Statistics.FileStatisticsException") > 0,
                "Failed to set message to null.");
        }

        /// <summary>
        /// Test ctor FileStatisticsException(string message),
        /// with message is emtpy, allowed.
        /// </summary>
        public void TestCtor1_MessageIsEmpty()
        {
            FileStatisticsException e = new FileStatisticsException(string.Empty);
            Assert.IsNotNull(e,
                "Failed to create instance of FileStatisticsException with message is empty.");
            Assert.AreEqual(string.Empty, e.Message,
                "Failed to set message to empty string.");
        }

        /// <summary>
        /// Test ctor FileStatisticsException(string message),
        /// with message is not empty, allowed.
        /// </summary>
        public void TestCtor1()
        {
            FileStatisticsException e = new FileStatisticsException(message);
            Assert.IsNotNull(e,
                "Failed to create instance of FileStatisticsException with message is non-empty.");
            Assert.AreEqual(message, e.Message,
                "Failed to set message to non-empty string.");
        }

        /// <summary>
        /// Test ctor FileStatisticsException(string message, Exception cause),
        /// with message is null, allowed
        /// </summary>
        public void TestCtor2_MessageIsNull()
        {
            FileStatisticsException e = new FileStatisticsException(null, cause);
            Assert.IsNotNull(e,
                "Failed to create instance of FileStatisticsException with message is null.");
            Assert.IsTrue(e.Message.IndexOf("TopCoder.File.Statistics.FileStatisticsException") > 0,
                "Failed to set message to null.");
            Assert.AreEqual(cause, e.InnerException, "Failed to set cause");
        }

        /// <summary>
        /// Test ctor FileStatisticsException(string message, Exception cause),
        /// with message is empty string, allowed
        /// </summary>
        public void TestCtor2_MessageIsEmpty()
        {
            FileStatisticsException e = new FileStatisticsException(string.Empty, cause);
            Assert.IsNotNull(e,
                "Failed to create instance of FileStatisticsException with message is null.");
            Assert.AreEqual(string.Empty, e.Message,
                "Failed to set message to empty string.");
            Assert.AreEqual(cause, e.InnerException, "Failed to set cause");
        }

        /// <summary>
        /// Test ctor FileStatisticsException(string message, Exception cause),
        /// with cause is null, allowed.
        /// </summary>
        public void TestCtor2_CauseIsNull()
        {
            FileStatisticsException e = new FileStatisticsException(message, null);
            Assert.IsNotNull(e,
                "Failed to create instance of FileStatisticsException with cause is null.");
            Assert.AreEqual(message, e.Message,
                "Failed to set message.");
            Assert.IsNull(e.InnerException, "Failed to set cause");
        }

        /// <summary>
        /// Test ctor FileStatisticsException(string message, Exception cause),
        /// with both arguments are valid, allowed.
        /// </summary>
        public void TestCtor2()
        {
            FileStatisticsException e = new FileStatisticsException(message, cause);
            Assert.IsNotNull(e,
                "Failed to create instance of FileStatisticsException with bothe arguments are valid.");
            Assert.AreEqual(message, e.Message,
                "Failed to set message.");
            Assert.AreEqual(cause, e.InnerException, "Failed to set cause");
        }
    }
}