using System;
using System.IO;
using System.Collections;

namespace TopCoder.File.Statistics.Processor
{
    /// <summary>
    /// Mock implementation of <see cref="FileProcessorBase"/> class, used to test <see cref="FileProcessorBase"/>.
    ///
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (C) 2005 TopCoder Inc., All Rights Reserved.</copyright>
    /// </summary>
    public class MockFileProcessorBase : FileProcessorBase
    {

        /// <summary>
        /// Get a list of all the supported metrics by this processor.
        /// This method is mostly for end user.
        /// It does not fulfill any responsibility in the current framework.
        /// </summary>
        ///
        /// <value>Represents the list of all the supported metrics.</value>
        public override IList SupportedMetrics
        {
            get
            {
                return new ArrayList();
            }
        }

        /// <summary>
        /// Constructor with both alias and matcher.
        /// </summary>
        ///
        /// <param name="alias">the alias for the processor</param>
        /// <param name="matcher">the file matcher</param>
        ///
        /// <exception cref="ArgumentNullException">if alias or matcher is null</exception>
        /// <exception cref="ArgumentException">if alias is empty after trimmed</exception>
        public MockFileProcessorBase(string alias, IFileMatcher matcher) : base(alias, matcher)
        {
        }

        /// <summary>
        /// This constructor loads configuration from the property. The non-empty alias and
        /// non-null file matcher are required. Any error will be wrapped in a
        /// <see cref="ConfigurationException"/>.
        /// </summary>
        ///
        /// <param name="nameSpace">not null and empty, the namespace to load config from.</param>
        /// <param name="prefix">
        /// can be empty, the prefix indicates the global property level.</param>
        ///
        /// <exception cref="ArgumentNullException">if nameSpace or prefix is null</exception>
        /// <exception cref="ArgumentException">if nameSpace is emtpy</exception>
        /// <exception cref="ConfigurationException">if config error occurs</exception>
        public MockFileProcessorBase(string nameSpace, string prefix) : base(nameSpace, prefix)
        {
        }

        /// <summary>
        /// Process the file and generate the result. A new result should be generated each time,
        /// whose keys are the metrics returned from <see cref="SupportedMetrics"/>.
        /// Mock implementation, always return null.
        /// </summary>
        ///
        /// <param name="file">the file to process</param>
        /// <returns>the stats result</returns>
        ///
        /// <exception cref="ArgumentNullException">if file is null</exception>
        /// <exception cref="IOException">if io operation fails</exception>
        /// <exception cref="FileProcessingException">if processor fails</exception>
        public override StatsResult Process(FileInfo file)
        {
            return null;
        }
    }
}