using System;
using System.IO;
using NUnit.Framework;

using TopCoder.Util.ConfigurationManager;

namespace TopCoder.File.Statistics
{
    /// <summary>
    /// The helper function for unit test.
    /// </summary>
    internal class UnitTestHelper
    {
        /// <summary>
        /// Represents the default config file.
        /// </summary>
        public const string DEFAULT_CONFIG = "../../test_files/conf/FileStatistics.xml";

        /// <summary>
        /// Represents the config file for command line.
        /// </summary>
        public const string COMMANDLINE_CONFIG = "../../test_files/conf/FileStatisticsCmd.xml";

        /// <summary>
        /// Represents the config file for command line.
        /// </summary>
        public const string INVALID_CONFIG = "../../test_files/conf/Invalid.xml";

        /// <summary>
        /// Represents the config file for magic number.
        /// </summary>
        public const string MAGIC_NUMBER_CONFIG = "../../test_files/conf/MagicNumber.xml";

        /// <summary>
        /// Represents the default namespace.
        /// </summary>
        public const string DEFAULT_NAMESPACE = "TopCoder.File.Statistics";


        /// <summary>
        /// Represents the namespace for invalid config.
        /// </summary>
        public const string INVALID_NAMESPACE = "TopCoder.File.Statistics.Invalid";

        /// <summary>
        /// Represents an instance of ConfigManager.
        /// </summary>
        private static ConfigManager cm = ConfigManager.GetInstance();

        /// <summary>
        /// Private constructor prevent from being initialized.
        /// </summary>
        private UnitTestHelper()
        {
        }

        /// <summary>
        /// Load the specified config file.
        /// </summary>
        ///
        /// <param name="fileName">the file to load</param>
        public static void LoadConfigFile(string fileName)
        {
            cm.LoadFile(fileName);
        }

        /// <summary>
        /// Remove the specified config file.
        /// </summary>
        ///
        /// <param name="fileName">the file to remove.</param>
        public static void RemoveConfigFile(string fileName)
        {
            cm.RemoveFile(fileName);
        }

        /// <summary>
        /// Delete file.
        /// </summary>
        ///
        /// <param name="fileName">the file to delete.</param>
        public static void DeleteFile(string fileName)
        {
            try
            {
                new FileInfo(fileName).Delete();
            }
            catch(Exception)
            {
                // ignore
            }
        }

        /// <summary>
        /// Read the file content and return.
        /// </summary>
        ///
        /// <param name="fileName">the file to read</param>
        /// <returns>the file content.</returns>
        public static string ReadFileContent(string fileName)
        {
            StreamReader reader = new StreamReader(fileName);
            string expected = reader.ReadToEnd();
            reader.Close();

            return expected;
        }

        /// <summary>
        /// Compare the content with file's content.
        /// </summary>
        ///
        /// <param name="content">the content to compare.</param>
        /// <param name="file">the file.</param>
        /// <param name="message">the tip message.</param>
        public static void VerifyResult(string content, string file, string message)
        {
            string expected = UnitTestHelper.ReadFileContent(file);
            Assert.AreEqual(expected, content, message);
        }
    }
}
